# Security center

## Overview

### Product introduction
The Security Center is a management tool based on the Kylin Security Framework (KYSEC). It provides comprehensive system security protection through features including system security scanning, account protection configuration, firewall settings, network control, virus defense, application source verification, application execution control,  peripheral device management and security tools - ensuring the security and stability of the system operating environment.

### Product Highlights
The Security Center integrates comprehensive security features including Security Scan, virus protection, account protection, firewall, vulnerability fixes, privacy security, trusted measurement, and security tools to ensure complete protection of the system operating environment.
- Security Scan: it provides multi-dimensional scanning and one click repair of account security, operation security and system security, which can automatically update vulnerability patches and find system security risks in time.
- Virus Defense: Provides a unified management interface for anti-virus software, compatible with multiple mainstream virus protection solutions to block malware intrusions in real time.
- Account Protection: Enforces password strength policies and account lockout mechanisms to strengthen system account security and prevent brute-force attacks.
- Firewall: Blocks unauthorized outbound connections and abnormal network activities to enhance network security.
- Vulnerability Repair: Detects and fixes system vulnerabilities to prevent exploitation.
- Privacy Security: Controls application access permissions to safeguard personal privacy and system file security.
- Trusted Measure: Leverages trusted computing technology to verify the integrity of critical system components, ensuring an untampered operating environment.
- Security Tools: Offers comprehensive protection tools including: Application source verification, Process anti-kill protection, Kernel module anti-unload, File tamper-proofing,  Application execution control, Device security management, Application network access control

## Getting started

### Software location
Click "Start Menu" of the operating system, select and click "security center" to open the security center software interface, as shown in Figure 1.

![Figure 1 Start menu (open security center)-big](image/1.png)

Click the "Start Menu" of the operating system, then click "Settings", and then click "security" to display the home page of the security center. Click the "view details" button of different modules to directly enter the corresponding module interface of the security center software, as shown in Figure 2.

![Figure 2 Settings (Open Security Center))-big](image/2.png)

### Get help
Click the icon in the security center software interface and click the "help" button to pop up the "user manual" pop-up window to display the relevant information of the security center's help manual, as shown in Figure 3.

![Figure 3 User Manual-big](image/3.png)

### Mode support
The display mode of security center software interface changes with the system theme, UKUI Menu—Settings—Personalized—Theme,as shown in Figure 4-5.

![Figure 4 Light Mode-big](image/4.png)

![Figure 5 Dark Mode-big](image/5.png)

### Language support
The security center software interface follows the system language setting by default and supports Chinese , Traditional, Mongolian, English and Tibetan, as shown in figures 6 to 10.

![Figure 6 English display-big](image/6.png)

![Figure 7 Traditional display-big](image/7.png)

![Figure 8 Mongolian display-big](image/8.png)

![Figure 9 Chinese display-big](image/9.png)

![Figure 10 Tibetan display-big](image/10.png)

## Security Scan

When the system has never undergone security scan, the homepage of security scan is shown in Figure 11.

![Figure 11 home page of Security Scan (never Security Scan)-big](image/11.png)

After the system examination, the security scan homepage displays the last examination time, the examination duration, the number of risk problems found and the number of examination scanning items, as shown in Figure 12.

![Figure 12 home page of Security Scan (display the last physical examination information)-big](image/12.png)

### Security Scan Items
Security examination items mainly include level I and level II physical examination items. Among them, there are three types of first-class examination items, including account detection, security detection and system detection; There are 18 items of level II examination, which are divided into risk problems and optimization suggestions. Risk Issues include: user file permissions, system file permissions, process protection, module anti uninstall, file protection, networking control, execution control, source check, remote service, firewall and address randomization; Optimization suggestions include: password strength, risk account, account locking, system update, application integrity, file integrity and vulnerability update, which are not included in risk issues.

### Last Examination Result
Click the "last examination" button to pop up the "view last examination" pop-up window, which displays the number of problems scanned last time, the number of successful repairs, the number of failed repairs, the number of items not repaired and the number of optimization suggestions, and displays the detailed system examination problem information in the list of last physical examination. The inspection items or problem descriptions can be quickly retrieved and located through the search box, As shown in Figure 13.

![Figure 13 Check the last physical examination-big](image/13.png)

### Scanning Process

Click the "start" button to conduct system security physical examination, dynamically display the physical examination scanning progress, and synchronously display the information of each physical examination item and physical examination results, as shown in Figure 14.

![Figure 14 safety physical examination scanning-big](image/14.png)

If no risk problem items and optimization suggestions are found in the safety physical examination, directly jump to the scanning completion page and prompt "no problem found, your computer is safe", as shown in Figure 15.

![Figure 15 Security Scaning completed (no risk problems and optimization suggestions found) -big](image/15.png)

If no risk problems are found in the safety examination and there are optimization suggestions, directly jump to the scanning completion page and display the contents of optimization suggestions, click the "go to Settings" button to jump to the repair page for manual repair, as shown in Figure 16.

![Figure 16 complete of Security Scaning (no risk problems are found and there are optimization suggestions) -big](image/16.png)

If risk problem items are found in the safety examination, the scanned risk problem items and optimization suggestions are displayed in the first column, and the risk problem items are prompted in red, as shown in Figure 17.

![Figure 17 complete of Security Scaning (risk problems found)-big](image/17.png)

### Problem fix

#### Single Repair
Click the problem risk item icon area to pop up the corresponding "risk details" pop-up window, which provides repair processing, ignore all and ignore single items, as shown in Figure 18. Click the "Deal" button to repair all the displayed risk problems; Click the "ignore all" button to ignore all risk problems, and the risk will still be scanned in the next physical examination; Click the "ignore" button to ignore the single item, and the single risk will still be scanned in the next physical examination.

![Figure 18 Risk details-big](image/18.png)

Click the optimization suggestion icon area to pop up the corresponding "optimization details" pop-up window, which provides the functions of go setting and ignore all, as shown in Figure 19. Click the "go to Settings" button to jump to the repair page for manual repair; Click the "ignore all" button to ignore all optimization problems, and the optimization suggestions will still be scanned in the next physical examination.

![Figure 19 Optimization details-big](image/19.png)

#### One click repair
All risk problem items are checked by default or can be unchecked. Click the "one click repair" button to repair all checked risk problem items with one click. It cannot be cancelled during the repair process, as shown in Figure 20.

![Figure 20 One click repair-big](image/20.png)

### Repair Complete
After the repair, there are no risk problems and optimization suggestions in the system, as shown in Figure 21. Click "Completed" to return to the home page of physical examination.

![Figure 21 Repair Completed (no risk in the system)-big](image/21.png)

After the repair, there are still risk problems in the system, as shown in Figure 22. If you need to repair this item, please have a physical examination again.

Click "Completed" to return to the home page of physical examination.

![Figure 22 Repair Completed (there are still risk problems)-big](image/22.png)

After the repair, there are still optimization suggestions in the system, as shown in Figure 23. Click the "Settings" button to jump to the system settings page to complete the manual repair.
Click "Completed" to return to the home page of physical examination.

![Figure 23 Repair Completed (there are still optimization suggestions) -big](image/23.png)


## Virus Defense

The security center provides virus protection to protect your system from threats. Click the "virus defense" tab in the left sidebar list to enter, as shown in Figure 24.

At present, the system integrates the Qianxin engine by default, and provides three ways to scan the system for viruses: fast killing, full killing and custom killing. There are two scanning modes: performance first and speed first.

The virus defense main interface displays the protection days of the corresponding virus engine, the installation time of the virus library, and the enabled virus protection engines.

![Figure 24 Virus Protection Homepage-big](image/24.png)

Click the intelligence scan button on the main interface of virus protection to enter the quick scan mode, as shown in Figure 25.

![Figure 25 Virus protection and rapid killing-big](image/25.png)

Click the "full disk scan" button on the main interface of virus protection to enter the full disk scan mode, as shown in Figure 26.

![Figure 26 Virus protection and complete killing-big](image/26.png)

Click the custom kill button on the virus protection main interface, and select the file or directory you want to kill in the custom kill pop-up window to start the custom kill, as shown in Figure 27.

![Figure 27 Virus protection and custom killing-big](image/27.png)

When the scanning is completed and there is a risk item, the path and operation of the risk item will be listed in the table. During the operation, you can click trust to put the virus into the trust zone. When the files in the trust zone are scanned next time, you will not be prompted that there is a risk. Click Details to view the corresponding virus type, virus description and risk path in the prompt window, as shown in Figure 28.

![Figure 28 Virus protection risk details-big](image/28.png)

In the upper right of the interface, there are two ways to deal with the virus: ignore all and deal with it immediately. Click ignore all to do nothing about the risk items. The next scan will still prompt that there is a risk. Click "process now" to put the selected virus file into the isolation area for isolation processing, and the original path file will be deleted, as shown in Figure 29.

![Figure 29 Virus protection scanning completed risk treatment-big](image/29.png)

After all risk items are processed, you will be prompted "all risk items are processed", as shown in Figure 30. Click "finish" to return to the virus scanning main interface.

![Figure 30 Virus protection risk treatment completed-big](image/30.png)

The isolated risk item files are displayed in the isolation area. You can view the path, virus name and isolation time of the specific risk item. You can select the risk item and click "recover" and "delete" to perform further operations on the risk item. The number of all risk items and the disk space occupied will be counted at the bottom of the interface, as shown in Figure 31.

![Figure 31 Virus protection isolation area-big](image/31.png)

Click the "restore" button to select whether to add the recovered file to the trust zone. If it is not checked, the risk item will be restored to the original path, and the next scan will still prompt that there is a risk. If it is checked, the risk item will be added to the trust zone, and the next scan will not prompt that there is a risk, as shown in Figure 32.

![Figure 32 Virus protection recovery quarantine file-big](image/32.png)

Trusted files and extensions are displayed in the trust zone. The path, type and adding time of trusted files or risk items are displayed in the file interface, as shown in Figure 33. Click "add" to add files or folders. Files added to the trust zone will not be scanned for risk items. Click "delete" to delete files or folders that have been added to the trust zone.

![Figure 33 Virus protection trust zone file interface-big](image/33.png)

The extension interface in the trust zone displays the name and adding time of the trusted extension. Click the "add" and "delete" buttons to add and delete the corresponding extension, as shown in Figure 34. Files ending with the extension in the trust zone will not be scanned for risk items.

![Figure 34 Virus protection trust zone extension interface-big](image/34.png)



## Account Protection
The security center provides system account password strength policy configuration and account locking policy configuration. Click the "account protection" button on the home page or the "account protection" tab in the left list to enter, as shown in Figure 35.

![Figure 35 Account Protection Homepage-big](image/35.png)

### Password Strength

The password strength function can be turned on or off. When it is enabled, the system account needs to comply with the requirements of the current password strength policy; When closed, the system account has no password strength limit.
Password Strength provides two configuration modes: recommendation and customization, as shown in Figure 36.
- Recommended: at least 8 characters, including 2 kinds of uppercase letters, lowercase letters, numbers and special symbols. The password is prohibited to include configuration policies such as user name; 
- Custom: customize the corresponding password strength policy as needed

![Figure 36 Custom Password Strength Policy-big](image/36.png)

The user defined password strength policy configuration interface provides the following settings:
-  Minimum Password Length, setting range 8 to 32 bits;
-  The password shall contain at least 1 to 4 character types;
- Password Validity: including 7 days, 30 days, 90 days, 180 days and permanent, which is permanent by default;
- Password Expiration Reminder includes 3 days, 7 days and 15 days. When the password validity time is set to 7 days, only 3 days can be selected for password expiration reminder;
- Password encryption, supporting two encryption methods: National Security SM3 and SHA-512.

### Account Lock
The account locking function can be turned on or off. When the account is opened, the system account needs to follow the requirements of the current account locking policy; When closed, the system account has no account locking restrictions.
The account Locking function provides the configuration of the number of consecutive wrong password entries and the account locking time. Number of consecutive wrong password entries: set the range 3 or from 5 to 10, and the default is 5; Account Locking Time: 1 minute, 3 minutes, 5 minutes, 10 minutes, 15 minutes and 30 minutes. The default is 3 minutes.

### Root Account Remote Login
The Root Account Remote Login feature controls whether remote access to the system's root account via SSH, RDP, or Telnet is permitted, reducing security risks.

Scope: Only restricts remote login to this device's root account - does not affect login access for other accounts.
Prerequisites: Corresponding packages (e.g. telnet) must be installed before this feature can be configured.
Firewall Coordination: The firewall's "Block Remote Access" function must be disabled to configure root account remote access settings.
![Figure 37  Hint to Disable remote access-big](image/37.png)


## Firewall

Security Center provides firewall and network control functions and intrusion detection tools to protect system network security, detect intrusion behaviors, and provide real-time alerts. Click the "Firewall" tab in the left sidebar, as shown in Figure 38.

![Figure 38 Firewall home page-big](image/38.png)

Set firewall access rules to protect system network security. Click the corresponding switch button to open or close the public or private network.
It provides two access modes: public network and office network.

- Public network: it is applicable to the network in public places, and the equipment is set to be undetectable;
- Private network: it is applicable to the network of home or work unit, and the equipment is set to be detectable;

When the two networks are all closed, the firewall access rules are all invalid, and the system is vulnerable to network attacks, as shown in Figure 39.

![Figure 39 Closing the firewall-big](image/39.png)

When the firewall is in public network or private network mode, you can click "advanced configuration" to configure customized firewall access rules, as shown in Figure 40.

![Figure 40 Custom firewall access rules-big](image/40.png)

In the firewall access rule list, click "add" to pop up the "new rule" pop-up window. You can manually enter the name information. Select the corresponding application, direction, network and protocol, enter the IP and port number, and click "OK" to complete the configuration, as shown in Figure 41.

![Figure 41 Add Rule-big](image/41.png)

In the firewall access rules list, right-clicking on a rule will display three options: "Disable", "Modify", and "Delete", allowing users to edit individual rules.

Batch operations for rules: In the firewall access rules list, check the boxes before the rules to select multiple rules in bulk.
Click "Delete" to remove all selected rules.
Click "Export" to export all selected firewall rules.

![Figure 42 Batch Delete Rules-big](image/42.png)


## Vulnerability Repair

If there is a vulnerability library package in the system and the Kylin Security Center software is successfully imported, the Kylin Security Center software will provide the vulnerability fixing function, as shown in Figure 43 on the home page.

![Figure 43 Vulnerability Fix Home Page-big](image/43.png)

### Vulnerability Scanning

Click the "Start" button to scan the vulnerability, dynamically display the scan progress, and display the scan results simultaneously, as shown in Figure 44.

![Figure 44 Vulnerability Fixes-Vulnerability Scanning-Scanning-big](image/44.png)

If no vulnerabilities are found, the scan is completed and the message "Scan completed, no vulnerabilities found" is displayed, as shown in Figure 45.

![Figure 45 Vulnerability Fixes-Vulnerability Scanning-No Vulnerabilities Found-big](image/45.png)

If a vulnerability is found during the scan, you can select the vulnerability to be fixed, and then click the One-Click Fix button to fix the vulnerability, as shown in Figure 46.

![Figure 46 Vulnerability Fixes-Vulnerability Scanning-Vulnerability List-big](image/46.png)

For each vulnerability, there is a View Details button, which you can click to view the specific information of the vulnerability, as shown in Figure 47.

![Figure 47 Vulnerability Fixes-Vulnerability Scanning-View Vulnerability Details-big](image/47.png)

There is a "Export Vulnerability Information" button at the bottom, after clicking, a pop-up window will be displayed to select the directory to be protected, and then save the vulnerability information scanned this time, as shown in Figure 48.

![Figure 48 Vulnerability Fixes-Vulnerability Scanning-Export Vulnerability Information-big](image/48.png)


### CVE Query

The CVE query function allows you to query the repair status and basic CVE information of a specified CVE system. Click CVE to pop up the CVE query window, as shown in Figure 49.

![Figure 49 Vulnerability Fixes-CVE Query-Query Window-big](image/49.png)

Enter the CVE number and click the search button to view the search result, as shown in Figure 50.

![Figure 50 Vulnerability Fixes-CVE Query-Query Result-big](image/50.png)


## Privacy Protection
Configure application access control policies to protect system privacy resources. The permission control function offers two operation modes, as shown in Figure 51:

- Enabled: System will restrict application access permissions to protect personal privacy
- Disabled: Allows all applications to access any system files

![Figure 51 Privacy Protection-Security Center-big](image/51.png)

Click the "Privacy Settings" button to access advanced privacy configuration. The list displays application names and types, as shown in Figure 52.

![Figure 52 Configuration - Privacy Protection-Security Center-big](image/52.png)

When selecting an application, the right panel displays the default directories containing user privacy data that the selected application can access. Use the Add and Delete buttons to modify directory permissions, as shown in Figure 53.

Clicking "Add" opens a directory selection dialog for adding individual directories. Select a privacy data directory and click "Delete" to remove access permissions for that application.

![Figure 53 Configuration - Privacy Protection-Security Center-big](image/53.png)


## Trust Measure



The trustworthiness measurement function depends on external conditions such as hardware environment, firmware requirements, and kernel drivers.


|Category | TPM2.0 Trusted Root | TEE (KyTEE) Trusted Root |
| ------------ | ------------------------------------------------------------ | ------------------------------------------------------------ |
|Hardware Environment | TPM2.0 module supporting national encryption algorithm (PCR Bank needs to support SM3). |The CPU architecture is' aarch64 'and supports Feiteng chips.                          |
|Firmware Requirements | The firmware needs to comply with and support the TCG EFI Protocol Specification standard specification proposed by the TCG Trusted Computing Organization. |The firmware needs to be adapted with KyTEE. For servers based on Feiteng chips produced by Great Wall, check the firmware version with the words FBS, such as G625FBS5GW.  |
|Kernel Driver | The system can map the device nodes of/dev/tpmX and/dev/tpmrmX corresponding to the hardware trusted root of TPM2, and generate device nodes:<br>`/dev/tpmX `, `/dev/tpmrmX ` (X represents a number, usually 0). |The device driver supports TEE, and the device nodes that generate TEE corresponding to/dev/teeX and/dev/teeprivX in the system generate device nodes:<br>`/dev/teeX `, `/dev/teeprivX ` (X represents a number, usually 0).  |

TPM adapted to the machines used during the development phase: Haiguang 3, Haiguang 4; TCM：S500C、 Haiguang 4; KYEE: Feiteng s2500.

After installing the libkytrusted security software package on hardware platforms that support TPM (Haiguang 3/4), TCM (S500C/Haiguang 4), or KYEE (Feiteng S2500), the Bank Kirin Security Center will activate the trusted measurement function. Click on the "Trusted Measurement" tab in the left menu bar to enter.

The homepage of the platform interface reliability measurement that supports TPM/TCM is shown in Figure 54.

![Figure 54 TPM/TCM Trust Measure Home Page-big](image/54.png)

The homepage of the platform interface reliability measurement that supports KYEE is shown in Figure 55.

![Figure 55 KYEE Trust Measure Home Page-big](image/55.png)

### Trusted Chain

It is used to display the complete trusted metric chain structure, which is composed of four parts: Trust Root, TPCM, UEFI and GRUB. The icon is blue in trusted status and red in untrusted status. Click the button to view the measurement details, as shown in Figure 56. 

![Figure 56 Trusted Chain-UEFI-big](image/56.png)


### System Startup Metrics

It is used to enable or disable the trusted metric function. Warning indicates that the trusted metric function is enabled and the user will be notified when the system environment changes are detected. Disable means that the trusted metric function is turned off and no device environment detection is performed. Note that the opening and closing here refer to the status of the next system startup, and a pop-up prompt will appear, as shown in Figure 57.

![Figure 57 System startup metrics-Effective After System Restart-big](image/57.png)

The "View Details" button on the right can view all measurement information when it is not closed,  the platform interface reliability measurement that supports TPM/TCM is shown in Figure 58, and the platform interface reliability measurement that supports KYEE is shown in Figure 59.

![Figure 58 TPM/TCM System startup metrics-View Details-big](image/58.png)

![Figure 59 KYEE System startup metrics-View Details-big](image/59.png)


## Security Tools
The Security Center provides a comprehensive suite of security tools to ensure complete system protection:
- Application Source Check: Configures installation policies for applications from unknown sources
- Process Anti-Kill Protection: Prevents specified processes from being accidentally or maliciously terminated during operation
- Kernel Module Anti-Unload: Blocks unauthorized or accidental removal of critical kernel modules
- File Tamper Protection: Ensures files cannot be illegally modified during storage or transmission
- Application Execution Control: Manages application execution policies to safeguard the system runtime environment
- Device Security: Implements multi-layered protection for external device connections, preventing both accidental loss and malicious theft of critical system data
- Application Network Access Control: Configures network access policies for applications to maintain network security

![Figure 60 Security Tools - All tools-big](image/60.png)

### Application Source Check
The security center provides application protection functions to protect your system from security threats. Click the "Application Protection" tab in the left sidebar to enter, as shown in Figure 61.
- Prevent: block the installation of applications from unknown sources; 
- Warning: please prompt me when installing applications from unknown sources; 
- Disable: allows the installation of applications from any source；

![Figure 61 Security Tools -  Application Source Check-Security Center-big](image/61.png)

When an application from an unknown source is installed, the system automatically pops up the "Security Center" pop-up window, providing permit install and prohibit install, as shown in Figure 62.

![Figure 62 Application Source Check-Security Center-big](image/62.png)

The application source check mode is blocking. When an application from an unknown source is installed, the system automatically pops up a "Security Center" pop-up window, prompting that the application installation has been blocked, as shown in Figure 63.

![Figure 63 Application Source Check-Security Center-big](image/63.png)


### Process Anti-Kill
The Process Anti-Kill feature can be enabled or disabled. When enabled, click "Advanced Configuration" in the upper-right corner to customize protected processes.

- Enabled: The system protects running processes, preventing malicious termination of protected processes.
- Disabled: Removes process protection restrictions, allowing normal termination of all processes.

![Figure 64 Security Tools - Process Anti-kill-big](image/64.png)

Click the "Advanced Configuration" button to access the advanced settings page. The policy configuration list displays: Sequence number, Process ID, Process name, Process path, Anti-kill protection switch. 

When multiple processes with identical names exist, their protection switches are consolidated. Enabling protection will safeguard all matching processes simultaneously. The list displays in collapsed view by default. Use the expand/collapse toggle to switch views, as shown in Figures 65-66.

![Figure 65 Process Anti-Kill - Advanced Configuration (Collapsed View) -big](image/65.png)

![Figure 66 Process Anti-Kill - Advanced Configuration (Expand View)-big](image/66.png)

### Kernel Module Anti-unloading
This feature can be enabled or disabled. When enabled, click ​​"Advanced Configuration"​​ in the upper-right corner to customize protected modules and prevent critical modules from being maliciously unloaded.
- Enabled: System protects specified modules, preventing unauthorized unloading of protected kernel modules
- Disabled: Removes module protection restrictions, allowing all modules to be unloaded

![Figure 67 Security tools - Kernel module anti-unloading-big](image/67.png)

The configuration list of kernel module anti uninstall policy includes serial number, kernel module name and anti uninstall protection switch, as shown in Figure 68.

![Figure 68 configuration - Kernel module anti-uninstall-big](image/68.png)


### File Tamper-proof
This security feature can be enabled or disabled. When activated, click "Advanced Configuration" in the upper-right corner to customize protected files and prevent critical system files from being maliciously modified or deleted.

- Enabled: System actively monitors and protects specified files against unauthorized modifications
- Disabled: Removes file protection restrictions, allowing all files to be modified

![Figure 69 Security tools - File Tamper-proof-big](image/69.png)

The contents displayed in the configuration list of file anti tamper policy include: serial number, file name, file path and release operation. After the protected file is released, the file is automatically cleared from the list, as shown in Figure 70.

![Figure 70 File Tamper-proof-big](image/70.png)

Click the "add" button to pop up the "select files to be protected" pop-up window. You can add files to be protected by yourself.

### Application Execution Control
Set the execution policy of the unauthenticated application to protect the security of the system operating environment. The execution control function provides three mode configurations, as shown in Figure 44.
- Block: block the execution of unauthenticated applications;
- Warning: please prompt me when executing an uncertified application;
- Close: allows execution of any application.

Script Execution Control: This security switch enables/disables system-wide control over script execution. When activated, it regulates the execution of bash/python/perl scripts and any scripts launched via ./ notation.

![Figure 71 Security Tools - Application Execution Control-big](image/71.png)

Click the "Advanced Configuration" button to pop up the "Advanced Configuration - Application Execution Control" pop-up window. The application execution control list includes serial number, file path, file type and current status, as shown in Figure 72.
- File types include: executable program, shared library, executable script and kernel module file.
- Current status includes: tampered, corrupted, and authenticated. Tampered: indicates that the file has been tampered with and the file type has not changed. Such files can be authenticated and de authenticated, or the corresponding software package can be reinstalled for manual recovery; Damaged: indicates that the file has been tampered with and the file type has been damaged. Such files cannot be authenticated or de authenticated, and can only be recovered or manually recovered by reinstalling the corresponding software package; Authenticated: indicates that the file has not been tampered with.
- Operations include authentication and cancellation. Authentication: re authenticate and trust the "tampered" application. After successful authentication, the current status changes to "authenticated" and the current application can be executed; Release: release the "tampered" or "authenticated" application from authentication and distrust. The application execution control list will automatically clear the application information, and the current application cannot be executed;
- By default, they are sorted in the order of "tampered", "damaged" and "authenticated".

![Figure 72 Advanced Configuration - Application Execution Control (brief information)-big](image/72.png)

Click the "Add" button to open a file/directory selection dialog, where you can: Add individual applications, Add entire directories (automatically scans all applications within)

Unauthorized Application Handling: When unverified applications attempt to execute, System displays "Security Center" prompt with options: Always Allow(whitelist permanently), Allow Once (temporary permission), Block Launch (default secure option). 

![Figure 73 Security Center - Application Execution Control (brief information)-big](image/73.png)

Block Mode Operation: When set to Block Mode, the system: Automatically prevents execution of unverified apps, Displays security notification with blocked status. 

![Figure 74 Security Center - Application Execution Control (brief information)-big](image/74.png)

Exclusion Policy Management: The exclusion list displays Entry number, Policy target, Policy type (Package/Directory/File), Management actions. Use the top-right controls to add new exclusions for files, directories, or packages.
- Policy Types: Software Packages (system-wide exceptions), Directories (folder-level exceptions), Individual Files (granular exceptions). 

![Figure 75 Advanced Configuration - Application Execution Control (Exclusion Policies)-big](image/75.png)


### Device security
Configure device security policies to prevent system data leakage. The device security feature can be enabled or disabled. When enabled, click "Advanced Configuration" in the upper-right corner to customize: Device permission controls, Connection policies, Device connection history.
- Enabled: New devices will be controlled according to configured policies when connected
- Disabled: Allows any device to connect without restrictions

![Figure 76 Security-Tools - Device Security Home Page-big](image/76.png)

Click the "Advanced Configuration" button to access the peripheral management advanced settings page, which contains three tabs: Device Permission Controls, Device Connection Policies, Device Connection Logs.

#### Device Permission Control
The device permission control list provides management functions for 8 device categories: USB ports, Optical drives, Wired network cards, Wireless network cards, Bluetooth, Printers, Cameras. Microphones.

Default State: All device types are enabled by default. When disabled, corresponding devices cannot be connected or used normally. 

Advanced Control Policies (for USB/Optical Drives):
- Read-only: Device can only read content (no writing)
- Read-write: Normal read/write operations permitted
- Read-execute: Allows reading and file execution (no writing)
- Full control: Permits read/write/execute operations
- Disabled: Complete access prohibition (USB only)
- 
![Figure 77 Security-Tools - Device Permission Control - enabled-big](image/77.png)

Blue icon indicates enabled status and gray icon indicates disabled status.

Interface-level restrictions automatically propagate to connected devices. Keyboard/mouse devices are exempt from USB port controls. Disabling USB ports automatically deactivates all USB storage devices

![Figure 78 Security-Tools - Device Permission Control - disabled-big](image/78.png)

#### Device Connection Policy
The device policy list displays configured security policies with the following fields: Entry Number, Device Name, Device Type, Device VID/PID, Serial Number, Policy Actions.
Policy Configuration Options varies by device type: Cameras: Enable/Disable.  USB Devices: Read-only/Read-write/Read-execute/Full-control/Disable.

![Figure 79 Policy management - device policy list-big](image/79.png)

The strategy control list can be manually operated to add device strategies. Click the "Add" button to pop up the "Device Add" pop-up window, as shown in Figure 64. Manually add the device name, device type (USB storage device, camera, Bluetooth device, printer, external optical drive), device information (VID, PID, and Serial), and policy control status (released or blocked). After successful addition, the device's policy control information will be automatically added to the policy control list.

![Figure 80 Policy management - add device-big](image/80.png)

The device information in the strategy control list can be exported. Click the "Export" button to select the export location. The exported document will be output in the specified format of XML, and the content of the exported file includes: device name, device information (VID, PID, and Serial), and policy control status.

The device information in the strategy control list can be imported, and the imported document will be input in the specified format of XML. The import operation will not clear the original policy information. New policies will be processed incrementally, and duplicate policies will be processed in an overwrite manner.

#### Device connection records

The connection record list can display device access history information (only records of the past 60 days are displayed), displayed in descending order of device access time. The list display content includes device name, device type, device VID, device PID, serial number, access time, The access duration and access status are shown in Figure 66.

The device access history information in the connection record list can be exported, and the exported file will be output in the prescribed format XML.

![Figure 81 Connection record list-export connection record-big](image/81.png)

When an unauthorized device is connected, the system automatically pops up the "Security Center" pop-up window to provide pass, stop, and stop once, as shown in Figure 82.

![Figure 82 Peripheral management-Security Center-big](image/82.png)

If the device is blocked by the device policy, the system automatically displays a Security Center pop-up window indicating that the device is blocked, as shown in Figure 83.

![Figure 83 Peripheral management-Security Center-big](image/83.png)


### Application Network Control

Set up application networking control policies to protect system network security. The networking control function provides on and off configuration, as shown in Figure 84.
- Enable: When unauthorized applications and services are detected connected to the internet, please prompt me;
- Close: Allow any application to connect to the internet.

![Figure 84 Security tools - Application Network Access Control -big](image/84.png)

When the networking control function is enabled, click the "Advanced Configuration" button to jump to the application networking control advanced configuration page. The application networking control list displays the following contents: serial number, name, application program path, and operation.

Users can configure networking control policies for individual applications or software packages, allowing or blocking settings, as shown in Figure 85.

![Figure 85 Advanced Configuration - Application Networking Control - big](image/85.png)

Click the Add App/Add Package button in the upper right corner to manually select an app and add it to the list. Select the application/software package in the list and click the delete button in the upper right corner to delete the network control configuration for that application/software package.

When unauthorized applications or services are connected to the network, the system automatically pops up a "Security Center" pop-up window, providing release, always block, and current ban, as shown in Figure 86.

![Figure 86 Network Control Security Center-big](image/86.png)

### Intrusion detection tools

Detecting known and unknown intrusion behaviors, real-time detection and warning, providing audit basis for system security. This feature requires the installation of an intrusion detection package (kguard desktop), otherwise it will not be displayed. As shown in Figure 87.

![Figure 87 Security Tools - Intrusion Detection Bug](image/87.png)

Click on the intrusion detection tool to bring up the intrusion detection interface, displaying alarm logs and alarm statistics data. Contains alarm levels. As shown in Figures 88 and 89.

![Figure 88 Security Tools - Alarm Log](image/88.png)

![Figure 89 Security Tools - Alarm Statistics](image/89.png)

Click on Settings to enter the intrusion detection settings page, which displays basic settings, defense measures, and AI network threat detection, as shown in Figure 90.

![Figure 90 Security Tools - Intrusion Detection - Settings](image/90.png)


## Settings

Security Center provides firewall, virus protection, and vulnerability fixing settings to meet different security protection requirements, as shown in Figure 91.

![Figure 91 Settings-Home Page-big](image/91.png)

### Firewall

The settings of the firewall include the settings of "private network" and "public network", and we can set the corresponding network connection according to the actual application scenario.

The settings for a private network include Outbound Connections and Inbound Connections, with Outbound Connections configured as Allow (default) and Blocked, and Inbound Connections configured as Allow, Blocked (default), and Block All Connections, as shown in Figure 92.

![Figure 92 Settings-Firewall Setting-Private network-big](image/92.png)

The settings for a public network include Outbound Connections and Inbound Connections, with Outbound Connections configured as Allow (default) and Blocked, and Inbound Connections configured as Allow, Blocked (default), and Block All Connections, as shown in Figure 93.

![Figure 93 Settings-Firewall Setting-Public network-big](image/93.png)

### Virus Protection

The settings of virus protection include basic settings, scan settings, and real-time protection, and we can configure different parameters according to the needs of protection.

After this function is enabled, the system can be scanned for real-time threat detection and virus scanning through the powerful computing and data analysis capabilities of the cloud, and the protection capability can be enhanced by combining local security protection with efficient resources in the cloud, as shown in Figure 94.

![Figure 90 Settings-Virus Protection Setting-Basic Setting-big](image/94.png)

In the scan settings, you can configure File Type, Compressed Packet Scan, and Macro Virus Scan. The virus protection feature scans all types of files by default, if you want to do a quick scan, you can select "Scan Programs and Documents Only (Recommended)" to narrow down the scanning scope; For "Compressed Package Scanning", the default scan skips compressed packages larger than 500MB and scans a maximum of 5 layers of compressed packages, which can be set according to the system environment. If you are worried about macro code in the scanned document, you can select Macro code in the scanned document to improve security, as shown in Figure 95.

![Figure 91 Settings-Virus Protection Setting-Scaning Setting-big](image/95.png)

In real-time protection, real-time file protection and virus handling mode are configured. Virus scanning of files as they are created is a preventative security measure designed to ensure that new files are checked as soon as they enter the system to prevent infection by viruses, malware, or other potential threats. It is enabled by default and is not recommended. When viruses are scanned out of the system, if you want to prevent irreversible damage to files during the virus removal process, and at the same time provide protection for file recovery and repair, you can select "Back up to quarantine when virus is removed", as shown in Figure 96.

![Figure 92 Settings-Virus Protection Setting-Real Time Protection-big](image/96.png)

### Vulnerability Fixes

Currently, we can set configurations such as automatic update of the vulnerability database and manual update of the vulnerability database, and also provide a button to upload the vulnerability database, as shown in Figure 97.

![Figure 93 Settings-Vulnerability Fixes-Home Page-big](image/97.png)

If you need to manually update a vulnerability database, you can select Manual Update Vulnerability Database, and then click Upload Vulnerability Database to prompt you to select a vulnerability database file, as shown in Figure 98.

![Figure 94 Settings-Vulnerability Fixes-Upload Vulnerability Database-big](image/98.png)

After the vulnerability database is imported to the Kylin Security Center software, a system notification will be displayed, as shown in Figure 99.

![Figure 95 Settings-Vulnerability Fixes-Import Success-big](image/99.png)

## Logs

Security Center provides a log feature that records and tracks various security-related events and activities of Security Center tools, as shown in Figure 100.

![Figure 96 Logs-Home Page-big](image/100.png)

## Appendix: Frequently Asked Questions and Solutions (FAQ)

##### I. Security Scan

- Q: How to repair application integrity?

A: In the Security Scan, the repair scheme is not provided temporarily. Users can view the file list in Security Tools - Application Execution Control - Advanced settings, certify or cancel the tampered files, and reinstall the corresponding software for the damaged files.
- Q: How to repair file integrity?

A: The repair scheme is not supported in the security examination. The user can view the optimization details on the scanning end page and manually modify the corresponding file according to the details prompt.
- Q: How to update vulnerabilities and systems?

A: When the security check-up prompts that the system is not updated or the vulnerability is not updated, the user can go to "Settings" according to the prompt to update the system or vulnerability. When the "Settings" cannot be updated, the user can manually install the vulnerability package of the corresponding version according to the prompt to repair the vulnerability risk item.
- Q: Why is the Application protection - Application Security Protection Control still closed after repairing the process protection?

A: The application protection control in application protection includes three functions (Process Protection, Module Anti Unloading and File protection). The application protection control is displayed as on only when all three functions are on. The application control can be started by repairing the three modules in the safety physical examination.
- Q: Why do files without owner and group disappear after security repair?

A: When abnormal files of owner and group are detected, it is determined that the file has the risk of being called to obtain administrator permissions. After repair, these files will be deleted. In order to avoid deleting files by mistake, users can view the risk details and check the files which files without owner and group before repair.

##### II. Virus Defense

- Q: Why does the security center not display the virus protection page after installing the third-party virus protection tool?

A: At present, it only supports qaxtray, and users can download it through the software store.



##### III. Account Protection

- Q：What should I do if the account is locked for a long time or permanently after a large number of incorrect password entries?

A: just restart the machine. At present, the system supports restart and reset, that is, after restarting the system, the locking times and locking time will be reset.
- Q: Why is it prompted to change the password?

A: there are two situations that force the user to change the password. First, the password expires. You can set the password validity in Security Center - Account Protection - password strength - user defined. Second, the password strength changes. The set user password does not meet the current password strength rules. You can modify the password according to the prompt.
- Q: Why is the custom password strength rule unsuccessful?

A: You can first check whether the set custom policy is the same as the recommendation mode. When the custom password policy is the same as the recommendation, it will automatically switch to the recommendation mode. The password policy rules of the recommended mode can be viewed by hovering the small question mark icon with the mouse.

- Q: Why is the account locking time abnormal?

A: when you are prompted that the account locking time is hundreds of days or more, the possible reason is that the user manually modifies the account locking time profile, or the system time is abnormal, that is, the system time when the account is locked is ahead of the current system. Restart the system to reset the locking time. In order to avoid abnormal account locking time, users need to pay attention to the system time and synchronize it with the network time.



##### IV. Firewall
- Q: How to handle the problem that the external network cannot access this computer?

A: On the premise that the equipment is connected to the network and the service is normal, the administrator user can enter the Security Center -> Firewall. First, turn off the two options in the firewall module to check whether the external network can be accessed. If so, it indicates that it is caused by the firewall, and then configure different firewall policies as required. The differences between firewall policies are as follows:

① Public network: The default access rule allows applications connected to the network to exit, and rejects any external applications to enter;

② Office network: The default access rule allows only networked applications to be outbound and inbound;
- Q: How to handle when the application cannot be networked?

A: the administrator user can enter the Security Center -> Firewall and network protection - networking control - advanced configuration to check whether the networking policy of the corresponding application is set to prohibit. If it is set to prohibit, the application will be prohibited from networking. Change its networkingQ: Why does the security center not display the virus protection page after installing the third-party virus protection tool? status as needed.

##### V. Application source check 

- Q: When the application source check operation box is grayed out, what should I do ?

A: The administrator user application source detection policy box is grayed out and cannot be clicked. Please use dpkg - L to check whether the libkylin-signtool signool package has been installed. If not, please install it
- Q: Why does the installation package pop up sometimes and not sometimes?

A: when the application source detection is set to the block mode, the unsigned software package will directly fail to install. In the warning mode, the installation authorization window will pop up when installing the unsigned software package, which needs to be confirmed by the user. You can use kylinsigntool - V xxx.deb to check whether the corresponding software package has been signed.



##### VI. Application execution control

- Q: Why is the application execution control - advanced configuration page blank?

A: The applications installed by default in the system are not displayed. Only the subsequently installed applications and tampered and damaged applications are displayed. You can click "details" to view the applications installed by default.
- Q: How to add user created executable files, scripts and dynamic libraries to kysec whitelist?

A: the administrator user can enter the Security Center - > Security Tools - > application execution control - > advanced configuration to add the corresponding file / directory to the white list.

- Q: The kysec flag of the file is not unknown, but it still has no permission to execute. What should I do?

A: first execute “ls -l” to check whether the current user has executable permissions on the current file; If yes, use “mount | grep data” to check whether the file has noexec in the mounting parameters of the partition. If yes, the administrator executes “sudo mount - o remount, exec / data”, and then executes.

- Q: Why application execution control list failed to add executable file?

A: if it is a script file, you need to add a header file to the corresponding script file. Secondly, you need Lsattr < filepath > to check whether the hidden attribute is set in the file. If so, you need to remove it and add it again.

- Q: How to judge the user's permission to add and view the application execution control list?

A: Application Execution Control limits the user's permission to add and view, as follows:

(1) Add permissions

① Super user (root user) can add files under all system directories;

② Administrator users (users with sudo permission) can only add files under the system directory with view permission, but cannot add system directory files without view permission (for example, other users cannot add operation directory files);

③ Ordinary users (users without sudo permission) cannot add files and can only view the file list information;

(2) Display rules

① The super user (root user) can display the applications added by all users;

② The administrator user (user with sudo authority) can only display the application with view authority and the application under the user's operation directory;

③ Ordinary users (users without sudo permission) can only display applications with view permission and applications under the user's operation directory;

- Q: Why does the execute control authorization pop-up appear during the use of the system?

A: the administrator user can enter the Security Center - > Security Tools - > application execution control - > advanced configuration to check whether the file status corresponding to the authorization window is tampered or damaged. For the tampered file, the user can authenticate or cancel the authentication status of the file. For the damaged file, the software package corresponding to the file needs to be reinstalled.

##### VII. Process Anti-kill

- Q: Why can't the application process be killed?

A: To check whether the corresponding process has enabled process anti killing, you can enter the Security Center - > Security Tools - > process anti killing list through the administrator user. After closing, it can be killed normally. The next time you need protection, you can open it again.

##### VIII. Kernel module anti-unloading

- Q: The kernel module cannot be uninstalled. What should I do?

A: The administrator user can enter the Security Center - > Security Tools - > kernel module anti uninstall, check whether the anti uninstall switch of the corresponding kernel module is turned on, and turn off the anti uninstall switch of the kernel module to uninstall normally. The next time you need protection, you can open it again.

##### IX. File Tamper-proof

- Q: Why can't the file be deleted?

A: to check whether the file is tamper proof, you can enter the Security Center - > Security Tools - > file tamper proof list through the administrator user. After cancellation, it can be deleted normally.

##### X. Application network control

- Q: Why can't you turn on the networked control and execute the control and protection control?

A: Use the terminal command getstatus to check the kysec status. When the kysec status is in soft mode, each function item cannot be opened normally. After using the command setstatus enable, each function item can be opened normally.

##### XI. Device Security
- Q: The device has been configured to release, but cannot be used after the device is inserted

A: Please enter the Security Center -> Security Tools -> Device Security ->Advanced Configuration -> Connection policy page, and check whether the corresponding device interface is enabled. If not, it needs to be enabled. If it is turned on, switch to the device control page again and check whether the corresponding device is turned on. If it is not, it needs to be turned on.

- Q: Device control authorization pop-up box. What should I do if I accidentally click permanent block

A: Please enter Security Center -> Security Tools -> Device Security ->Advanced Configuration -> Manage device policies ->Device Policy. You can reset the device policy on this page.